@@ -29,9 +29,10 @@ inline const QString& _valueOf(const QString& x) { return x; }
 inline const QString  _valueOf(size_t x) { return QString::number((uint)x); }
 
 // some debug macros
-#define dbg(x)    qDebug(#x " is <%s>", _valueOf(x).toLatin1().constData())
-#define dbs(x)    qDebug(_valueOf(x).toLatin1().constData())
-#define dbp(s, x) qDebug(QString(s).arg(_valueOf(x)).toLatin1().constData())
+#define constlatin(x) (_valueOf(x).toLatin1().constData())
+#define dbg(x)    qDebug(#x " is <%s>", constlatin(x))
+#define dbs(x)    qDebug(constlatin(x), "")
+#define dbp(s, x) qDebug(constlatin(_valueOf(s).arg(x)), "")
 #define db1       qDebug("Mark Nr. 1")
 #define db2       qDebug("Mark Nr. 2")
 #define db3       qDebug("Mark Nr. 3")
@@ -66,27 +67,6 @@ namespace QGit {
 	// minimum git version required
 	extern const QString GIT_VERSION;
 
-	// key bindings
-	enum KeyType {
-		KEY_UP,
-		KEY_DOWN,
-		SHIFT_KEY_UP,
-		SHIFT_KEY_DOWN,
-		KEY_LEFT,
-		KEY_RIGHT,
-		CTRL_PLUS,
-		CTRL_MINUS,
-		KEY_U,
-		KEY_D,
-		KEY_DELETE,
-		KEY_B,
-		KEY_BCKSPC,
-		KEY_SPACE,
-		KEY_R,
-		KEY_P,
-		KEY_F
-	};
-
 	// tab pages
 	enum TabType {
 		TAB_REV,
@@ -333,7 +313,7 @@ public:
 	const QString longLog() const { setup(); return mid(lLogStart, lLogLen); }
 	const QString diff() const { setup(); return mid(diffStart, diffLen); }
 
-	QVector<int> lanes, childs;
+        QVector<int> lanes, children;
 	QVector<int> descRefs;     // list of descendant refs index, normally tags
 	QVector<int> ancRefs;      // list of ancestor refs index, normally tags
 	QVector<int> descBranches; // list of descendant branches index
