@@ -219,10 +219,10 @@ QModelIndex FileHistory::parent(const QModelIndex&) const {
 
 const QString FileHistory::timeDiff(unsigned long secs) const {
 
-	uint days  =  secs / (3600 * 24);
-	uint hours = (secs - days * 3600 * 24) / 3600;
-	uint min   = (secs - days * 3600 * 24 - hours * 3600) / 60;
-	uint sec   =  secs - days * 3600 * 24 - hours * 3600 - min * 60;
+        ulong days  =  secs / (3600 * 24);
+        ulong hours = (secs - days * 3600 * 24) / 3600;
+        ulong min   = (secs - days * 3600 * 24 - hours * 3600) / 60;
+        ulong sec   =  secs - days * 3600 * 24 - hours * 3600 - min * 60;
 	QString tmp;
 	if (days > 0)
 		tmp.append(QString::number(days) + "d ");
@@ -330,7 +330,9 @@ void Git::checkEnvironment() {
 	isTextHighlighterFound = run("source-highlight -V", &version);
 	errorReportingEnabled = true;
 	if (isTextHighlighterFound)
-		dbp("Found %1", version.section('\n', 0, 0));
+		textHighlighterVersionFound = version.section('\n', 0, 0);
+	else
+		textHighlighterVersionFound = "GNU source-highlight not installed";
 }
 
 void Git::userInfo(SList info) {
@@ -425,7 +427,7 @@ void Git::setTextCodec(QTextCodec* tc) {
 	if (name == "Big5-HKSCS")
 		name = "Big5";
 
-	run("git repo-config i18n.commitencoding " + name);
+   run("git config i18n.commitencoding " + name);
 }
 
 QTextCodec* Git::getTextCodec(bool* isGitArchive) {
@@ -435,7 +437,7 @@ QTextCodec* Git::getTextCodec(bool* isGitArchive) {
 		return NULL;
 
 	QString runOutput;
-	if (!run("git repo-config --get i18n.commitencoding", &runOutput))
+   if (!run("git config i18n.commitencoding", &runOutput))
 		return NULL;
 
 	if (runOutput.isEmpty()) // git docs says default is utf-8
@@ -594,7 +596,7 @@ const QString Git::getRevInfo(SCRef sha) {
 
 	QString refsInfo;
 	if (type & BRANCH) {
-		const QString cap(type & CUR_BRANCH ? "Head: " : "Branch: ");
+		const QString cap(type & CUR_BRANCH ? "HEAD: " : "Branch: ");
 		refsInfo =  cap + getRefName(sha, BRANCH).join(" ");
 	}
 	if (type & RMT_BRANCH)
@@ -828,27 +830,27 @@ const QString Git::getLaneParent(SCRef fromSHA, int laneNum) {
 	return "";
 }
 
-const QStringList Git::getChilds(SCRef parent) {
+const QStringList Git::getChildren(SCRef parent) {
 
-	QStringList childs;
+        QStringList children;
 	const Rev* r = revLookup(parent);
 	if (!r)
-		return childs;
+                return children;
 
-	for (int i = 0; i < r->childs.count(); i++)
-		childs.append(revData->revOrder[r->childs[i]]);
+        for (int i = 0; i < r->children.count(); i++)
+                children.append(revData->revOrder[r->children[i]]);
 
-	// reorder childs by loading order
-	QStringList::iterator itC(childs.begin());
-	for ( ; itC != childs.end(); ++itC) {
+        // reorder children by loading order
+        QStringList::iterator itC(children.begin());
+        for ( ; itC != children.end(); ++itC) {
 		const Rev* r = revLookup(*itC);
 		(*itC).prepend(QString("%1 ").arg(r->orderIdx, 6));
 	}
-	childs.sort();
-	for (itC = childs.begin(); itC != childs.end(); ++itC)
+        children.sort();
+        for (itC = children.begin(); itC != children.end(); ++itC)
 		(*itC) = (*itC).section(' ', -1, -1);
 
-	return childs;
+        return children;
 }
 
 const QString Git::getShortLog(SCRef sha) {
@@ -923,7 +925,17 @@ MyProcess* Git::getFile(SCRef fileSha, QObject* receiver, QByteArray* result, SC
 	  change is committed.
 	*/
 	if (fileSha == ZERO_SHA)
+
+#ifdef Q_OS_WIN32
+    {
+		QString winPath = quote(fileName);
+		winPath.replace("/", "\\");
+		runCmd = "type " + winPath;
+    }
+#else
 		runCmd = "cat " + quote(fileName);
+#endif
+
 	else {
 		if (fileSha.isEmpty()) // deleted
 			runCmd = "git diff-tree HEAD HEAD"; // fake an empty file reading
@@ -1269,7 +1281,7 @@ const QString Git::getDesc(SCRef sha, QRegExp& shortLogRE, QRegExp& longLogRE,
 				ts << formatList(patches, "Patch");
 			} else {
 				ts << formatList(c->parents(), "Parent", false);
-				ts << formatList(getChilds(sha), "Child", false);
+                                ts << formatList(getChildren(sha), "Child", false);
 				ts << formatList(getDescendantBranches(sha), "Branch", false);
 				ts << formatList(getNearTags(!optGoDown, sha), "Follows");
 				ts << formatList(getNearTags(optGoDown, sha), "Precedes");
@@ -1297,7 +1309,7 @@ const QString Git::getDesc(SCRef sha, QRegExp& shortLogRE, QRegExp& longLogRE,
 
 		SCRef ref = reSHA.cap(0).mid(2);
 		const Rev* r = (ref.length() == 40 ? revLookup(ref) : revLookup(getRefSha(ref)));
-		if (r) {
+		if (r && r->sha() != ZERO_SHA_RAW) {
 			QString slog(r->shortLog());
 			if (slog.isEmpty()) // very rare but possible
 				slog = r->sha();
@@ -1546,6 +1558,20 @@ bool Git::applyPatchFile(SCRef patchPath, bool fold, bool isDragDrop) {
 	return run(runCmd + quote(patchPath));
 }
 
+const QStringList Git::sortShaListByIndex(SCList shaList) {
+
+	QStringList orderedShaList;
+	FOREACH_SL (it, shaList)
+		appendNamesWithId(orderedShaList, *it, QStringList(*it), true);
+
+	orderedShaList.sort();
+	QStringList::iterator itN(orderedShaList.begin());
+	for ( ; itN != orderedShaList.end(); ++itN) // strip 'idx'
+		(*itN) = (*itN).section(' ', -1, -1);
+
+        return orderedShaList;
+}
+
 bool Git::formatPatch(SCList shaList, SCRef dirPath, SCRef remoteDir) {
 
 	bool remote = !remoteDir.isEmpty();
@@ -1559,7 +1585,7 @@ bool Git::formatPatch(SCList shaList, SCRef dirPath, SCRef remoteDir) {
 	if (remote)
 		runCmd.append(" --keep-subject");
 
-	runCmd.append(" -o " + dirPath);
+	runCmd.append(" -o " + quote(dirPath));
 	if (!FPOpt.isEmpty())
 		runCmd.append(" " + FPOpt.trimmed());
 
@@ -1671,7 +1697,7 @@ bool Git::mkPatchFromWorkDir(SCRef msg, SCRef patchFile, SCList files) {
  		return false;
 
 	QString runOutput;
-	if (!run("git diff -C HEAD -- " + quote(files), &runOutput))
+	if (!run("git diff --no-ext-diff -C HEAD -- " + quote(files), &runOutput))
 		return false;
 
 	const QString patch("Subject: " + msg + "\n---\n" + runOutput);
