@@ -154,6 +154,7 @@ public:
 	bool isNothingToCommit();
 	bool isUnknownFiles() const { return (workingDirInfo.otherFiles.count() > 0); }
 	bool isTextHighlighter() const { return isTextHighlighterFound; }
+	const QString textHighlighterVersion() const { return textHighlighterVersionFound; }
 	bool isMainHistory(const FileHistory* fh) { return (fh == revData); }
 	MyProcess* getDiff(SCRef sha, QObject* receiver, SCRef diffToSha, bool combined);
 	const QString getWorkDirDiff(SCRef fileName = "");
@@ -170,7 +171,7 @@ public:
 	const QString getLastCommitMsg();
 	const QString getNewCommitMsg();
 	const QString getLaneParent(SCRef fromSHA, int laneNum);
-	const QStringList getChilds(SCRef parent);
+        const QStringList getChildren(SCRef parent);
 	const QStringList getNearTags(bool goDown, SCRef sha);
 	const QStringList getDescendantBranches(SCRef sha, bool shaOnly = false);
 	const QString getShortLog(SCRef sha);
@@ -184,6 +185,7 @@ public:
 	const QStringList getRefName(SCRef sha, RefType type, QString* curBranch = NULL) const;
 	const QStringList getAllRefNames(uint mask, bool onlyLoaded);
 	const QStringList getAllRefSha(uint mask);
+	const QStringList sortShaListByIndex(SCList shaList);
 	void getWorkDirFiles(SList files, SList dirs, RevFile::StatusFlag status);
 	QTextCodec* getTextCodec(bool* isGitArchive);
 	bool formatPatch(SCList shaList, SCRef dirPath, SCRef remoteDir = "");
@@ -328,6 +330,7 @@ private:
 	bool isStGIT;
 	bool isGIT;
 	bool isTextHighlighterFound;
+	QString textHighlighterVersionFound;
 	bool loadingUnAppliedPatches;
 	bool fileCacheAccessed;
 	int patchesStillToFind;
