@@ -36,7 +36,7 @@ const QString Git::getLocalDate(SCRef gitDate) {
 		return localDate;
 
 	QDateTime d;
-	d.setTime_t(gitDate.toULong());
+        d.setTime_t(gitDate.toUInt());
 	localDate = d.toString(Qt::LocalDate);
 	localDates[gitDate] = localDate;
 	return localDate;
@@ -748,11 +748,11 @@ void Git::on_loaded(FileHistory* fh, ulong byteSize, int loadTime,
 
 			fh->loadTime += loadTime;
 
-			uint kb = byteSize / 1024;
-			float mbs = (float)byteSize / fh->loadTime / 1000;
+                        ulong kb = byteSize / 1024;
+                        double mbs = (double)byteSize / fh->loadTime / 1000;
 			QString tmp;
-			tmp.sprintf("Loaded %i revisions  (%i KB),   "
-			            "time elapsed: %i ms  (%.2f MB/s)",
+                        tmp.sprintf("Loaded %i revisions  (%li KB),   "
+                                    "time elapsed: %i ms  (%.2f MB/s)",
 			            fh->revs.count(), kb, fh->loadTime, mbs);
 
 			if (!tryFollowRenames(fh))
@@ -830,7 +830,7 @@ bool Git::populateRenamedPatches(SCRef renamedSha, SCList newNames, FileHistory*
 	SCRef lastFileSha = line.section(' ', 3, 3);
 	if (prevFileSha == lastFileSha) // just renamed
 		runOutput.clear();
-	else if (!run("git diff -r --full-index " + prevFileSha + " " + lastFileSha, &runOutput))
+	else if (!run("git diff --no-ext-diff -r --full-index " + prevFileSha + " " + lastFileSha, &runOutput))
 		return false;
 
 	SCRef prevFile = line.section('\t', -1, -1);
@@ -840,7 +840,7 @@ bool Git::populateRenamedPatches(SCRef renamedSha, SCList newNames, FileHistory*
 	// save the patch, will be used later to create a
 	// proper graft sha with correct parent info
 	if (fh) {
-		QString tmp(!runOutput.isEmpty() ? runOutput : "diff --\nsimilarity index 100%\n");
+		QString tmp(!runOutput.isEmpty() ? runOutput : "diff --no-ext-diff --\nsimilarity index 100%\n");
 		fh->renamedPatches.insert(renamedSha, tmp);
 	}
 	return true;
@@ -1198,7 +1198,7 @@ void Git::flushFileNames(FileNamesLoader& fl) {
 	QVector<int>& dirs = fl.rfDirs;
 
 	b.clear();
-	b.resize(2 * dirs.size() * sizeof(int));
+        b.resize(2 * dirs.size() * sizeof(int));
 
 	int* d = (int*)(b.data());
 
@@ -1395,7 +1395,7 @@ void Git::indexTree() {
 
 			Rev* p = const_cast<Rev*>(revLookup(r->parent(y)));
 			if (p) {
-				p->childs.append(i);
+                                p->children.append(i);
 
 				if (p->descBrnMaster == -1)
 					p->descBrnMaster = isB ? r->orderIdx : r->descBrnMaster;
@@ -1420,9 +1420,9 @@ void Git::indexTree() {
 			rr->ancRefs.clear();
 			rr->ancRefs.append(i);
 		}
-		for (int y = 0; y < r->childs.count(); y++) {
+                for (int y = 0; y < r->children.count(); y++) {
 
-			Rev* c = const_cast<Rev*>(revLookup(ro[r->childs[y]]));
+                        Rev* c = const_cast<Rev*>(revLookup(ro[r->children[y]]));
 			if (c) {
 				if (c->ancRefsMaster == -1)
 					c->ancRefsMaster = isTag ? r->orderIdx:r->ancRefsMaster;
@@ -1467,151 +1467,170 @@ const QStringList Rev::parents() const {
 }
 
 int Rev::indexData(bool quick, bool withDiff) const {
-/*
+    /*
   This is what 'git log' produces:
 
-	- a possible one line with "Final output:\n" in case of --early-output option
-	- one line with "log size" + len of this record
-	- one line with boundary info + sha + an arbitrary amount of parent's sha
-	- one line with committer name + e-mail
-	- one line with author name + e-mail
-	- one line with author date as unix timestamp
-	- zero or more non blank lines with other info, as the encoding FIXME
-	- one blank line
-	- zero or one line with log title
-	- zero or more lines with log message
-	- zero or more lines with diff content (only for file history)
-	- a terminating '\0'
+        - a possible one line with "Final output:\n" in case of --early-output option
+        - one line with "log size" + len of this record
+        - one line with boundary info + sha + an arbitrary amount of parent's sha
+        - one line with committer name + e-mail
+        - one line with author name + e-mail
+        - one line with author date as unix timestamp
+        - zero or more non blank lines with other info, as the encoding FIXME
+        - one blank line
+        - zero or one line with log title
+        - zero or more lines with log message
+        - zero or more lines with diff content (only for file history)
+        - a terminating '\0'
 */
-	const int last = ba.size() - 1;
-	int logSize = 0, idx = start;
-	int logEnd, revEnd;
+    static int error = -1;
+    static int shaLength = 40; // from git ref. spec.
+    static int shaEndlLength = shaLength + 1; // an sha key + \n
+    static int shaXEndlLength = shaLength + 2; // an sha key + X marker + \n
+    static char finalOutputMarker = 'F'; // marks the beginning of "Final output" string
+    static char logSizeMarker = 'l'; // marks the beginning of "log size" string
+    static int logSizeStrLength = 9; // "log size"
+    static int asciiPosOfZeroChar = 48; // char "0" has value 48 in ascii table
 
-	// direct access is faster then QByteArray.at()
-	const char* data = ba.constData();
-	char* fixup = const_cast<char*>(data); // to build '\0' terminating strings
+    const int last = ba.size() - 1;
+    int logSize = 0, idx = start;
+    int logEnd, revEnd;
 
-	if (start + 42 > last) // at least sha + 'X' + 'X' + '\n' + must be present
-		return -1;
+    // direct access is faster then QByteArray.at()
+    const char* data = ba.constData();
+    char* fixup = const_cast<char*>(data); // to build '\0' terminating strings
 
-	if (data[start] == 'F') // "Final output", let caller handle this
-		return (ba.indexOf('\n', start) != -1 ? -2 : -1);
+    if (start + shaXEndlLength > last) // at least sha header must be present
+        return -1;
 
-	// parse log size if present
-	if (data[idx] == 'l') { // 'log size xxx\n'
+    if (data[start] == finalOutputMarker) // "Final output", let caller handle this
+        return (ba.indexOf('\n', start) != -1 ? -2 : -1);
 
-		idx += 9; // move idx to beginning of log size
-		int tmp;
-		while ((tmp = data[idx++]) != '\n')
-			logSize = logSize * 10 + tmp - 48;
-	}
-	// idx points to the boundary information
-	if (++idx + 42 > last)
-		return -1;
+    // parse   'log size xxx\n'   if present -- from git ref. spec.
+    if (data[idx] == logSizeMarker) {
+        idx += logSizeStrLength; // move idx to beginning of log size value
 
-	shaStart = idx;
+        // parse log size value
+        int digit;
+        while ((digit = data[idx++]) != '\n')
+            logSize = logSize * 10 + digit - asciiPosOfZeroChar;
+    }
+    // idx points to the boundary information, which has the same length as an sha header.
+    if (++idx + shaXEndlLength > last)
+        return error;
 
-	// ok, now shaStart is valid but msgSize
-	// could be still 0 if not available
-	logEnd = shaStart - 1 + logSize;
-	if (logEnd > last)
-		return -1;
+    shaStart = idx;
 
-	idx += 40; // now points to 'X' place holder
+    // ok, now shaStart is valid but msgSize could be still 0 if not available
+    logEnd = shaStart - 1 + logSize;
+    if (logEnd > last)
+        return error;
 
-	fixup[idx] = '\0'; // we want sha to be a '\0' terminated ascii string
+    idx += shaLength; // now points to 'X' place holder
 
-	parentsCnt = 0;
+    fixup[idx] = '\0'; // we want sha to be a '\0' terminated ascii string
 
-	if (data[idx + 2] == '\n') // initial revision
-		++idx;
-	else do {
-		parentsCnt++;
-		idx += 41;
+    parentsCnt = 0;
 
-		if (idx + 1 >= last)
-		    break;
+    if (data[idx + 2] == '\n') // initial revision
+        ++idx;
+    else do {
+        parentsCnt++;
+        idx += shaEndlLength;
 
-		fixup[idx] = '\0'; // we want parents '\0' terminated
+        if (idx + 1 >= last)
+            break;
 
-	} while (data[idx + 1] != '\n');
+        fixup[idx] = '\0'; // we want parents '\0' terminated
 
-	++idx; // now points to the trailing '\n' of sha line
+    } while (data[idx + 1] != '\n');
 
-	// check for !msgSize
-	if (withDiff || !logSize) {
+    ++idx; // now points to the trailing '\n' of sha line
 
-		revEnd = (logEnd > idx) ? logEnd - 1: idx;
-		do { // search for "\n\0" to handle (rare) cases of '\0'
-		     // in content, see c42012 and bb8d8a6 in Linux tree
-			revEnd = ba.indexOf('\0', revEnd + 1);
-			if (revEnd == -1)
-				return -1;
+    // check for !msgSize
+    if (withDiff || !logSize) {
 
-		} while (data[revEnd - 1] != '\n');
+        revEnd = (logEnd > idx) ? logEnd - 1: idx;
+        do { // search for "\n\0" to handle (rare) cases of '\0'
+            // in content, see c42012 and bb8d8a6 in Linux tree
+            revEnd = ba.indexOf('\0', revEnd + 1);
+            if (revEnd == -1)
+                return -1;
 
-	} else
-		revEnd = logEnd;
+        } while (data[revEnd - 1] != '\n');
 
-	if (revEnd > last) // after this point we know to have the whole record
-		return -1;
+    } else
+        revEnd = logEnd;
 
-	// ok, now revEnd is valid but logEnd could be not if !logSize
-	// in case of diff we are sure content will be consumed so
-	// we go all the way
-	if (quick && !withDiff)
-		return ++revEnd;
+    if (revEnd > last) // after this point we know to have the whole record
+        return error;
 
-	comStart = ++idx;
-	idx = ba.indexOf('\n', idx); // committer line end
-	if (idx == -1) {
-		dbs("ASSERT in indexData: unexpected end of data");
-		return -1;
-	}
+    // ok, now revEnd is valid but logEnd could be not if !logSize
+    // in case of diff we are sure content will be consumed so
+    // we go all the way
+    if (quick && !withDiff)
+        return ++revEnd;
 
-	autStart = ++idx;
-	idx = ba.indexOf('\n', idx); // author line end
-	if (idx == -1) {
-		dbs("ASSERT in indexData: unexpected end of data");
-		return -1;
-	}
-	autDateStart = ++idx;
-	idx += 11; // date length + trailing '\n'
+    // commiter
+    comStart = ++idx;
+    idx = ba.indexOf('\n', idx); // committer line end
+    if (idx == -1) {
+        dbs("ASSERT in indexData: unexpected end of data");
+        return -1;
+    }
 
-	diffStart = diffLen = 0;
-	if (withDiff) {
-		diffStart = logSize ? logEnd : ba.indexOf("\ndiff ", idx);
+    // author
+    autStart = ++idx;
+    idx = ba.indexOf('\n', idx); // author line end
+    if (idx == -1) {
+        dbs("ASSERT in indexData: unexpected end of data");
+        return -1;
+    }
 
-		if (diffStart != -1 && diffStart < revEnd)
-			diffLen = revEnd - ++diffStart;
-		else
-			diffStart = 0;
-	}
-	if (!logSize)
-		logEnd = diffStart ? diffStart : revEnd;
+    // author date in Unix format (seconds since epoch)
+    autDateStart = ++idx;
+    idx = ba.indexOf('\n', idx); // author date end without '\n'
+    if (idx == -1) {
+        dbs("ASSERT in indexData: unexpected end of data");
+        return -1;
+    }
+    // if no error, point to trailing \n
+    ++idx;
 
-	// ok, now logEnd is valid and we can handle the log
-	sLogStart = idx;
+    diffStart = diffLen = 0;
+    if (withDiff) {
+        diffStart = logSize ? logEnd : ba.indexOf("\ndiff ", idx);
 
-	if (logEnd < sLogStart) { // no shortlog no longLog
+        if (diffStart != -1 && diffStart < revEnd)
+            diffLen = revEnd - ++diffStart;
+        else
+            diffStart = 0;
+    }
+    if (!logSize)
+        logEnd = diffStart ? diffStart : revEnd;
 
-		sLogStart = sLogLen = 0;
-		lLogStart = lLogLen = 0;
-	} else {
-		lLogStart = ba.indexOf('\n', sLogStart);
-		if (lLogStart != -1 && lLogStart < logEnd - 1) {
+    // ok, now logEnd is valid and we can handle the log
+    sLogStart = idx;
 
-			sLogLen = lLogStart - sLogStart; // skip sLog trailing '\n'
-			lLogLen = logEnd - lLogStart; // include heading '\n' in long log
+    if (logEnd < sLogStart) { // no shortlog no longLog
 
-		} else { // no longLog
-			sLogLen = logEnd - sLogStart;
-			if (data[sLogStart + sLogLen - 1] == '\n')
-				sLogLen--; // skip trailing '\n' if any
+        sLogStart = sLogLen = 0;
+        lLogStart = lLogLen = 0;
+    } else {
+        lLogStart = ba.indexOf('\n', sLogStart);
+        if (lLogStart != -1 && lLogStart < logEnd - 1) {
 
-			lLogStart = lLogLen = 0;
-		}
-	}
-	indexed = true;
-	return ++revEnd;
+            sLogLen = lLogStart - sLogStart; // skip sLog trailing '\n'
+            lLogLen = logEnd - lLogStart; // include heading '\n' in long log
+
+        } else { // no longLog
+            sLogLen = logEnd - sLogStart;
+            if (data[sLogStart + sLogLen - 1] == '\n')
+                sLogLen--; // skip trailing '\n' if any
+
+            lLogStart = lLogLen = 0;
+        }
+    }
+    indexed = true;
+    return ++revEnd;
 }
